@@ -93,7 +93,7 @@ class Kullback:
             self,
             x: np.ndarray,
             y: np.ndarray
-    ) -> np.float:
+    ) -> float:
         if np.size(x) != np.size(y):
             raise Exception("'x' and 'y' must have the same size")
         if (
