@@ -36,16 +36,11 @@ class L21rows:
                  [default: gamma=1]
     """
 
-    def __init__(self, gamma: Union[float, np.ndarray] = 1):
-        if np.any(gamma <= 0):
-            raise Exception(
-                "'gamma' (or all of its components if it is an array)" +
-                " must be strictly positive"
-            )
-        self.gamma = gamma
+    def __init__(self):
+        pass
 
-    def prox(self, x: np.ndarray) -> np.ndarray:
-        return L2Norm(gamma=self.gamma, axis=1).prox(x)
+    def prox(self, x: np.ndarray, gamma: Union[float, np.ndarray] = 1.0) -> np.ndarray:
+        return L2Norm(axis=1).prox(x, gamma)
 
     def __call__(self, x: np.ndarray) -> float:
-        return L2Norm(gamma=self.gamma, axis=1)(x)
+        return L2Norm(axis=1)(x)
