@@ -49,6 +49,6 @@ class Linf(Max):
         abs_x = np.abs(x)
         return np.sign(x) * Max(axis=self.axis).prox(abs_x, gamma)
 
-    def __call__(self, x: np.ndarray) -> np.float:
+    def __call__(self, x: np.ndarray) -> float:
         linf_x = np.max(np.abs(x), self.axis)
-        return np.sum(linf_x)
\ No newline at end of file
+        return np.sum(linf_x)
