@@ -20,7 +20,6 @@ from typing import Union
 import numpy as np
 from proxop.scalar.AbsValue import AbsValue
 from proxop.utils.prox_svd import prox_svd
-from proxop.utils.fun_svd import fun_svd
 
 
 class NuclearNorm:
@@ -50,5 +49,5 @@ class NuclearNorm:
             )
         return prox_svd(x, gamma, AbsValue().prox)
 
-    def __call__(self, x: np.ndarray) -> np.float:
-        return fun_svd(x, 1, AbsValue())
+    def __call__(self, x: np.ndarray) -> float:
+        return np.linalg.norm(x, ord='nuc')
