@@ -55,5 +55,5 @@ class PermutationInvariant:
 
         return prox_svd(x, gamma, self.class_phi().prox)
 
-    def __call__(self, x):
+    def __call__(self, x) -> float:
         return fun_svd(x, 1, self.class_phi().prox)
