@@ -114,7 +114,7 @@ class PersAbsDiff:
 
         return tuple([prox_p, prox_q])
 
-    def __call__(self, y: np.ndarray) -> np.float:
+    def __call__(self, y: np.ndarray) -> float:
         if np.size(y) <= 1:
             y = np.reshape(y, (-1))
 
