@@ -49,5 +49,5 @@ class Rank:
     ) -> np.ndarray:
         return prox_svd(x, gamma, L0Norm().prox)
 
-    def __call__(self, x: np.ndarray) -> np.float:
+    def __call__(self, x: np.ndarray) -> float:
         return fun_svd(x, 1, L0Norm())
