@@ -116,7 +116,7 @@ class Renyi:
             self,
             x: np.ndarray,
             y: np.ndarray
-    ) -> np.float:
+    ) -> float:
         if np.any(x < 0) or np.any(y < 0) or np.any((y == 0) * (x != 0)):
             return np.inf
 
