@@ -26,7 +26,7 @@ from proxop.utils.fun_svd import fun_svd
 class Spectral:
     r"""Compute the proximity operator and the evaluation of gamma*f.
 
-    Where f is the funtion definded as:
+    Where f is the function defined as:
 
                          f(x)= ||X||_S
 
@@ -44,16 +44,9 @@ class Spectral:
         pass
 
     def prox(self, x: np.ndarray, gamma: Union[float, np.ndarray] = 1) -> np.ndarray:
-        self._check(x, gamma)
-        return prox_svd(x, gamma, Linf().prox)
-
-    def __call__(self, x: np.ndarray) -> np.float:
-        return fun_svd(x, 1, Linf())
-
-    def _check(self, x, gamma):
         if np.any(gamma <= 0) or np.size(gamma) > 1:
             raise Exception("'gamma'  must be a strictly positive scalar")
-        if len(np.shape(x)) != 2:
-            raise ValueError(
-                "'x' must be an (M,N) -array_like ( representing an M*N matrix )"
-            )
+        return prox_svd(x, gamma, Linf().prox)
+
+    def __call__(self, x: np.ndarray) -> float:
+        return fun_svd(x, 1, Linf())
