@@ -83,5 +83,5 @@ class LogSum:
         )
         return prox_x
 
-    def __call__(self, x: np.ndarray) -> np.float:
+    def __call__(self, x: np.ndarray) -> float:
         return np.sum(np.log(self.delta + np.abs(x)))
