@@ -84,7 +84,7 @@ class HingeLoss:
         prox_x[mask] = x[mask]
         return prox_x
 
-    def __call__(self, x: np.ndarray) -> np.float:
+    def __call__(self, x: np.ndarray) -> float:
         if np.size(x) > 1 and (not isinstance(x, np.ndarray)):
             x = np.array(x)
         fun_x = np.maximum(1 - x, 0)
