@@ -13,18 +13,17 @@ def pava_python(x):
 
     for every 'j' and 'k' in {1,...,N}, where N = size(x,1).
     """
-    sz = np.size(x, 0)
+    N = np.size(x, 0)
+
     res = np.zeros(np.size(x))
-    for n in range(sz):
+    cum_sum = np.reshape(1 + np.arange(N**2) % N, (N, N))
+    cum_sum = 1 + cum_sum - np.arange(1, N+1).reshape((N, 1))
+    cum_sum = np.cumsum(x) / cum_sum
+    for n in range(N):
         max_sum = -np.inf
-        for j in range(n + 1):
-            min_sum = np.inf
-            for k in range(n, sz):
-                sum_xl = 1 / (k - j + 1) * np.sum(x[j:(k + 1)])
-                if sum_xl < min_sum:
-                    min_sum = sum_xl
+        for j in range(n+1):
+            min_sum = np.min( cum_sum, axis=1) 
             if min_sum > max_sum:
                 max_sum = min_sum
         res[n] = max_sum
-
     return res
